RESOURCES_MAP = {
    # AWS resources
    'aws_accessanalyzer_analyzer': None,
    'aws_accessanalyzer_archive_rule': None,
    'aws_account_alternate_contact': None,
    'aws_account_primary_contact': None,
    'aws_account_region': None,
    'aws_acm_certificate': 'aws.security.ACM',
    'aws_acm_certificate_validation': None,
    'aws_acmpca_certificate': None,
    'aws_acmpca_certificate_authority': None,
    'aws_acmpca_certificate_authority_certificate': None,
    'aws_acmpca_permission': None,
    'aws_acmpca_policy': None,
    'aws_ami': 'aws.compute.AMI',
    'aws_ami_copy': None,
    'aws_ami_from_instance': None,
    'aws_ami_ids': None,
    'aws_ami_launch_permission': None,
    'aws_amplify_app': 'aws.mobile.Amplify',
    'aws_amplify_backend_environment': None,
    'aws_amplify_branch': None,
    'aws_amplify_domain_association': None,
    'aws_amplify_webhook': None,
    'aws_api_gateway_account': None,
    'aws_api_gateway_api_key': None,
    'aws_api_gateway_authorizer': None,
    'aws_api_gateway_base_path_mapping': None,
    'aws_api_gateway_client_certificate': None,
    'aws_api_gateway_deployment': None,
    'aws_api_gateway_documentation_part': None,
    'aws_api_gateway_documentation_version': None,
    'aws_api_gateway_domain_name': None,
    'aws_api_gateway_export': None,
    'aws_api_gateway_gateway_response': None,
    'aws_api_gateway_integration': None,
    'aws_api_gateway_integration_response': None,
    'aws_api_gateway_method': None,
    'aws_api_gateway_method_response': None,
    'aws_api_gateway_method_settings': None,
    'aws_api_gateway_model': None,
    'aws_api_gateway_request_validator': None,
    'aws_api_gateway_resource': 'aws.network.APIGateway',
    'aws_api_gateway_rest_api': None,
    'aws_api_gateway_rest_api_policy': None,
    'aws_api_gateway_sdk': None,
    'aws_api_gateway_stage': None,
    'aws_api_gateway_usage_plan': None,
    'aws_api_gateway_usage_plan_key': None,
    'aws_api_gateway_vpc_link': 'aws.network.Privatelink',
    'aws_apigatewayv2_api': None,
    'aws_apigatewayv2_api_mapping': None,
    'aws_apigatewayv2_authorizer': None,
    'aws_apigatewayv2_deployment': None,
    'aws_apigatewayv2_domain_name': None,
    'aws_apigatewayv2_export': None,
    'aws_apigatewayv2_integration': None,
    'aws_apigatewayv2_integration_response': None,
    'aws_apigatewayv2_model': None,
    'aws_apigatewayv2_route': None,
    'aws_apigatewayv2_route_response': None,
    'aws_apigatewayv2_stage': None,
    'aws_apigatewayv2_vpc_link': 'aws.network.Privatelink',
    'aws_app_cookie_stickiness_policy': None,
    'aws_appautoscaling_policy': None,
    'aws_appautoscaling_scheduled_action': 'aws.compute.AutoScaling ',
    'aws_appautoscaling_target': None,
    'aws_appconfig_application': None,
    'aws_appconfig_configuration_profile': None,
    'aws_appconfig_deployment': None,
    'aws_appconfig_deployment_strategy': None,
    'aws_appconfig_environment': None,
    'aws_appconfig_extension': None,
    'aws_appconfig_extension_association': None,
    'aws_appconfig_hosted_configuration_version': None,
    'aws_appfabric_app_authorization': None,
    'aws_appfabric_app_authorization_connection': None,
    'aws_appfabric_app_bundle': None,
    'aws_appfabric_ingestion': None,
    'aws_appfabric_ingestion_destination': None,
    'aws_appflow_connector_profile': None,
    'aws_appflow_flow': None,
    'aws_appintegrations_data_integration': None,
    'aws_appintegrations_event_integration': None,
    'aws_applicationinsights_application': None,
    'aws_appmesh_gateway_route': None,
    'aws_appmesh_mesh': 'aws.network.AppMesh',
    'aws_appmesh_route': None,
    'aws_appmesh_virtual_gateway': None,
    'aws_appmesh_virtual_node': None,
    'aws_appmesh_virtual_router': None,
    'aws_appmesh_virtual_service': None,
    'aws_apprunner_auto_scaling_configuration_version': None,
    'aws_apprunner_connection': None,
    'aws_apprunner_custom_domain_association': None,
    'aws_apprunner_default_auto_scaling_configuration_version': None,
    'aws_apprunner_deployment': None,
    'aws_apprunner_hosted_zone_id': None,
    'aws_apprunner_observability_configuration': None,
    'aws_apprunner_service': 'aws.compute.AppRunner',
    'aws_apprunner_vpc_connector': None,
    'aws_apprunner_vpc_ingress_connection': None,
    'aws_appstream_directory_config': None,
    'aws_appstream_fleet': None,
    'aws_appstream_fleet_stack_association': None,
    'aws_appstream_image': None,
    'aws_appstream_image_builder': None,
    'aws_appstream_stack': 'aws.enduser.Appstream20',
    'aws_appstream_user': 'asw.general.User',
    'aws_appstream_user_stack_association': None,
    'aws_appsync_api_cache': None,
    'aws_appsync_api_key': None,
    'aws_appsync_datasource': None,
    'aws_appsync_domain_name': None,
    'aws_appsync_domain_name_api_association': None,
    'aws_appsync_function': None,
    'aws_appsync_graphql_api': 'aws.integration.Appsync',
    'aws_appsync_resolver': None,
    'aws_appsync_type': None,
    'aws_arn': None,
    'aws_athena_data_catalog': 'aws.analytics.Athena',
    'aws_athena_database': 'aws.analytics.Athena',
    'aws_athena_named_query': 'aws.analytics.Athena',
    'aws_athena_prepared_statement': 'aws.analytics.Athena',
    'aws_athena_workgroup': 'aws.analytics.Athena',
    'aws_auditmanager_account_registration': None,
    'aws_auditmanager_assessment': None,
    'aws_auditmanager_assessment_delegation': None,
    'aws_auditmanager_assessment_report': None,
    'aws_auditmanager_control': None,
    'aws_auditmanager_framework': None,
    'aws_auditmanager_framework_share': None,
    'aws_auditmanager_organization_admin_account_registration': None,
    'aws_autoscaling_attachment': None,
    'aws_autoscaling_group': 'aws.compute.EC2AutoScaling',
    'aws_autoscaling_group_tag': None,
    'aws_autoscaling_lifecycle_hook': None,
    'aws_autoscaling_notification': None,
    'aws_autoscaling_policy': None,
    'aws_autoscaling_schedule': 'aws.compute.EC2AutoScaling',
    'aws_autoscaling_traffic_source_attachment': None,
    'aws_autoscalingplans_scaling_plan': None,
    'aws_availability_zone': None,
    'aws_backup_framework': None,
    'aws_backup_global_settings': None,
    'aws_backup_plan': 'aws.storage.Backup',
    'aws_backup_region_settings': None,
    'aws_backup_report_plan': None,
    'aws_backup_selection': None,
    'aws_backup_vault': None,
    'aws_backup_vault_lock_configuration': None,
    'aws_backup_vault_notifications': None,
    'aws_backup_vault_policy': None,
    'aws_batch_compute_environment': None,
    'aws_batch_job_definition': 'aws.compute.Batch',
    'aws_batch_job_queue': None,
    'aws_batch_scheduling_policy': None,
    'aws_bcmdataexports_export': None,
    'aws_bedrock_custom_model': None,
    'aws_bedrock_foundation_model': None,
    'aws_bedrock_guardrail': None,
    'aws_bedrock_model_invocation_logging_configuration': None,
    'aws_bedrock_provisioned_model_throughput': None,
    'aws_bedrockagent_agent': None,
    'aws_bedrockagent_agent_action_group': None,
    'aws_bedrockagent_agent_alias': None,
    'aws_bedrockagent_agent_knowledge_base_association': None,
    'aws_bedrockagent_agent_versions': None,
    'aws_bedrockagent_data_source': None,
    'aws_bedrockagent_knowledge_base': None,
    'aws_billing_service_account': None,
    'aws_budgets_budget': 'aws.cost.Budgets',
    'aws_budgets_budget_action': None,
    'aws_caller_identity': None,
    'aws_canonical_user_id': None,
    'aws_ce_anomaly_monitor': None,
    'aws_ce_anomaly_subscription': None,
    'aws_ce_cost_allocation_tag': None,
    'aws_ce_cost_category': None,
    'aws_ce_tags': None,
    'aws_chatbot_slack_channel_configuration': 'aws.management.Chatbot',
    'aws_chatbot_slack_workspace': None,
    'aws_chatbot_teams_channel_configuration': None,
    'aws_chime_voice_connector': 'aws.business.Chime',
    'aws_chime_voice_connector_group': None,
    'aws_chime_voice_connector_logging': None,
    'aws_chime_voice_connector_origination': None,
    'aws_chime_voice_connector_streaming': None,
    'aws_chime_voice_connector_termination': None,
    'aws_chime_voice_connector_termination_credentials': None,
    'aws_chimesdkmediapipelines_media_insights_pipeline_configuration': None,
    'aws_chimesdkvoice_global_settings': None,
    'aws_chimesdkvoice_sip_media_application': None,
    'aws_chimesdkvoice_sip_rule': None,
    'aws_chimesdkvoice_voice_profile_domain': None,
    'aws_cleanrooms_collaboration': None,
    'aws_cleanrooms_configured_table': None,
    'aws_cloud9_environment_ec2': 'aws.devtools.Cloud9Resource',
    'aws_cloud9_environment_membership': 'aws.general.User',
    'aws_cloudcontrolapi_resource': None,
    'aws_cloudformation_export': None,
    'aws_cloudformation_stack': 'aws.management.CloudformationStack',
    'aws_cloudformation_stack_set': None,
    'aws_cloudformation_stack_set_instance': None,
    'aws_cloudformation_type': None,
    'aws_cloudfront_cache_policy': None,
    'aws_cloudfront_continuous_deployment_policy': None,
    'aws_cloudfront_distribution': 'aws.network.CF',
    'aws_cloudfront_field_level_encryption_config': None,
    'aws_cloudfront_field_level_encryption_profile': None,
    'aws_cloudfront_function': None,
    'aws_cloudfront_key_group': None,
    'aws_cloudfront_key_value_store': None,
    'aws_cloudfront_log_delivery_canonical_user_id': None,
    'aws_cloudfront_monitoring_subscription': None,
    'aws_cloudfront_origin_access_control': None,
    'aws_cloudfront_origin_access_identities': None,
    'aws_cloudfront_origin_access_identity': None,
    'aws_cloudfront_origin_request_policy': None,
    'aws_cloudfront_public_key': None,
    'aws_cloudfront_realtime_log_config': None,
    'aws_cloudfront_response_headers_policy': None,
    'aws_cloudfrontkeyvaluestore_key': None,
    'aws_cloudhsm_v2_cluster': None,
    'aws_cloudhsm_v2_hsm': 'aws.security.CloudHSM',
    'aws_cloudsearch_domain': 'aws.analytics.Cloudsearch',
    'aws_cloudsearch_domain_service_access_policy': None,
    'aws_cloudtrail': 'aws.management.Cloudtrail',
    'aws_cloudtrail_event_data_store': None,
    'aws_cloudtrail_organization_delegated_admin_account': None,
    'aws_cloudtrail_service_account': None,
    'aws_cloudwatch_composite_alarm': None,
    'aws_cloudwatch_dashboard': None,
    'aws_cloudwatch_event_api_destination': None,
    'aws_cloudwatch_event_archive': None,
    'aws_cloudwatch_event_bus': 'aws.integration.EventbridgeCustomEventBusResource',
    'aws_cloudwatch_event_bus_policy': None,
    'aws_cloudwatch_event_connection': None,
    'aws_cloudwatch_event_endpoint': None,
    'aws_cloudwatch_event_permission': None,
    'aws_cloudwatch_event_rule': 'aws.management.CloudwatchRule',
    'aws_cloudwatch_event_source': None,
    'aws_cloudwatch_event_target': None,
    'aws_cloudwatch_log_account_policy': None,
    'aws_cloudwatch_log_data_protection_policy': None,
    'aws_cloudwatch_log_data_protection_policy_document': None,
    'aws_cloudwatch_log_destination': None,
    'aws_cloudwatch_log_destination_policy': None,
    'aws_cloudwatch_log_group': None,
    'aws_cloudwatch_log_metric_filter': None,
    'aws_cloudwatch_log_resource_policy': 'aws.security.IAMPermissions',
    'aws_cloudwatch_log_stream': None,
    'aws_cloudwatch_log_subscription_filter': None,
    'aws_cloudwatch_metric_alarm': 'aws.management.CloudwatchAlarm',
    'aws_cloudwatch_metric_stream': None,
    'aws_cloudwatch_query_definition': None,
    'aws_codeartifact_authorization_token': None,
    'aws_codeartifact_domain': None,
    'aws_codeartifact_domain_permissions_policy': None,
    'aws_codeartifact_repository': None,
    'aws_codeartifact_repository_endpoint': None,
    'aws_codeartifact_repository_permissions_policy': None,
    'aws_codebuild_project': 'aws.devtools.Codebuild',
    'aws_codebuild_report_group': None,
    'aws_codebuild_resource_policy': 'aws.security.IAMPermissions',
    'aws_codebuild_source_credential': None,
    'aws_codebuild_webhook': None,
    'aws_codecatalyst_dev_environment': None,
    'aws_codecatalyst_project': None,
    'aws_codecatalyst_source_repository': None,
    'aws_codecommit_approval_rule_template': None,
    'aws_codecommit_approval_rule_template_association': None,
    'aws_codecommit_repository': 'aws.devtools.Codecommit',
    'aws_codecommit_trigger': None,
    'aws_codedeploy_app': None,
    'aws_codedeploy_deployment_config': 'aws.devtools.Codedeploy',
    'aws_codedeploy_deployment_group': None,
    'aws_codeguruprofiler_profiling_group': None,
    'aws_codegurureviewer_repository_association': None,
    'aws_codepipeline': 'aws.devtools.Codepipeline',
    'aws_codepipeline_custom_action_type': None,
    'aws_codepipeline_webhook': None,
    'aws_codestarconnections_connection': 'aws.devtools.Codestar',
    'aws_codestarconnections_host': None,
    'aws_codestarnotifications_notification_rule': None,
    'aws_cognito_identity_pool': 'aws.security.Cognito',
    'aws_cognito_identity_pool_provider_principal_tag': None,
    'aws_cognito_identity_pool_roles_attachment': None,
    'aws_cognito_identity_provider': None,
    'aws_cognito_managed_user_pool_client': None,
    'aws_cognito_resource_server': None,
    'aws_cognito_risk_configuration': None,
    'aws_cognito_user': 'aws.general.User',
    'aws_cognito_user_group': 'aws.general.Users',
    'aws_cognito_user_in_group': 'aws.general.User',
    'aws_cognito_user_pool': 'aws.security.Cognito',
    'aws_cognito_user_pool_client': None,
    'aws_cognito_user_pool_domain': None,
    'aws_cognito_user_pool_signing_certificate': None,
    'aws_cognito_user_pool_ui_customization': None,
    'aws_cognito_user_pools': 'aws.security.Cognito',
    'aws_comprehend_document_classifier': None,
    'aws_comprehend_entity_recognizer': 'aws.ml.Comprehend',
    'aws_config_aggregate_authorization': None,
    'aws_config_config_rule': 'aws.management.Config',
    'aws_config_configuration_aggregator': None,
    'aws_config_configuration_recorder': None,
    'aws_config_configuration_recorder_status': None,
    'aws_config_conformance_pack': None,
    'aws_config_delivery_channel': None,
    'aws_config_organization_conformance_pack': None,
    'aws_config_organization_custom_policy_rule': None,
    'aws_config_organization_custom_rule': None,
    'aws_config_organization_managed_rule': None,
    'aws_config_remediation_configuration': None,
    'aws_config_retention_configuration': None,
    'aws_connect_bot_association': None,
    'aws_connect_contact_flow': None,
    'aws_connect_contact_flow_module': None,
    'aws_connect_hours_of_operation': None,
    'aws_connect_instance': 'aws.engagement.Connect',
    'aws_connect_instance_storage_config': None,
    'aws_connect_lambda_function_association': None,
    'aws_connect_phone_number': None,
    'aws_connect_prompt': None,
    'aws_connect_queue': None,
    'aws_connect_quick_connect': None,
    'aws_connect_routing_profile': None,
    'aws_connect_security_profile': None,
    'aws_connect_user': 'aws.general.User',
    'aws_connect_user_hierarchy_group': None,
    'aws_connect_user_hierarchy_structure': None,
    'aws_connect_vocabulary': None,
    'aws_controltower_control': 'aws.management.ControlTower',
    'aws_controltower_controls': None,
    'aws_controltower_landing_zone': None,
    'aws_cur_report_definition': 'aws.cost.CostAndUsageReport',
    'aws_customer_gateway': 'aws.network.VPCCustomerGateway',
    'aws_customerprofiles_domain': None,
    'aws_customerprofiles_profile': None,
    'aws_dataexchange_data_set': None,
    'aws_dataexchange_revision': None,
    'aws_datapipeline_pipeline': 'aws.analytics.DataPipeline',
    'aws_datapipeline_pipeline_definition': None,
    'aws_datasync_agent': None,
    'aws_datasync_location_azure_blob': None,
    'aws_datasync_location_efs': None,
    'aws_datasync_location_fsx_lustre_file_system': None,
    'aws_datasync_location_fsx_ontap_file_system': None,
    'aws_datasync_location_fsx_openzfs_file_system': None,
    'aws_datasync_location_fsx_windows_file_system': None,
    'aws_datasync_location_hdfs': None,
    'aws_datasync_location_nfs': None,
    'aws_datasync_location_object_storage': None,
    'aws_datasync_location_s3': None,
    'aws_datasync_location_smb': None,
    'aws_datasync_task': None,
    'aws_datazone_domain': None,
    'aws_datazone_environment_blueprint': None,
    'aws_datazone_environment_blueprint_configuration': None,
    'aws_datazone_environment_profile': None,
    'aws_datazone_form_type': None,
    'aws_datazone_glossary': None,
    'aws_datazone_glossary_term': None,
    'aws_datazone_project': None,
    'aws_dax_cluster': None,
    'aws_dax_parameter_group': None,
    'aws_dax_subnet_group': None,
    'aws_db_cluster_snapshot': None,
    'aws_db_event_categories': None,
    'aws_db_event_subscription': None,
    'aws_db_instance': 'aws.database.RDS',
    'aws_db_instance_automated_backups_replication': None,
    'aws_db_instance_role_association': None,
    'aws_db_instances': None,
    'aws_db_option_group': None,
    'aws_db_parameter_group': None,
    'aws_db_proxy': None,
    'aws_db_proxy_default_target_group': None,
    'aws_db_proxy_endpoint': None,
    'aws_db_proxy_target': None,
    'aws_db_snapshot': None,
    'aws_db_snapshot_copy': None,
    'aws_db_subnet_group': None,
    'aws_default_network_acl': 'aws.network.Nacl',
    'aws_default_route_table': 'aws.network.RouteTable',
    'aws_default_security_group': None,
    'aws_default_subnet': None,
    'aws_default_tags': None,
    'aws_default_vpc': None,
    'aws_default_vpc_dhcp_options': None,
    'aws_detective_graph': 'aws.security.Detective',
    'aws_detective_invitation_accepter': None,
    'aws_detective_member': None,
    'aws_detective_organization_admin_account': None,
    'aws_detective_organization_configuration': None,
    'aws_devicefarm_device_pool': None,
    'aws_devicefarm_instance_profile': None,
    'aws_devicefarm_network_profile': None,
    'aws_devicefarm_project': 'aws.mobile.DeviceFarm',
    'aws_devicefarm_test_grid_project': None,
    'aws_devicefarm_upload': None,
    'aws_devopsguru_event_sources_config': None,
    'aws_devopsguru_notification_channel': None,
    'aws_devopsguru_resource_collection': None,
    'aws_devopsguru_service_integration': None,
    'aws_directory_service_conditional_forwarder': None,
    'aws_directory_service_directory': 'aws.security.DS',
    'aws_directory_service_log_subscription': None,
    'aws_directory_service_radius_settings': None,
    'aws_directory_service_region': None,
    'aws_directory_service_shared_directory': None,
    'aws_directory_service_shared_directory_accepter': None,
    'aws_directory_service_trust': None,
    'aws_dlm_lifecycle_policy': None,
    'aws_dms_certificate': None,
    'aws_dms_endpoint': None,
    'aws_dms_event_subscription': None,
    'aws_dms_replication_config': 'aws.database.DMS',
    'aws_dms_replication_instance': None,
    'aws_dms_replication_subnet_group': None,
    'aws_dms_replication_task': None,
    'aws_dms_s3_endpoint': None,
    'aws_docdb_cluster': None,
    'aws_docdb_cluster_instance': None,
    'aws_docdb_cluster_parameter_group': None,
    'aws_docdb_cluster_snapshot': None,
    'aws_docdb_engine_version': None,
    'aws_docdb_event_subscription': None,
    'aws_docdb_global_cluster': None,
    'aws_docdb_orderable_db_instance': None,
    'aws_docdb_subnet_group': None,
    'aws_docdbelastic_cluster': None,
    'aws_dx_bgp_peer': None,
    'aws_dx_connection': None,
    'aws_dx_connection_association': None,
    'aws_dx_connection_confirmation': None,
    'aws_dx_gateway': None,
    'aws_dx_gateway_association': None,
    'aws_dx_gateway_association_proposal': None,
    'aws_dx_hosted_connection': None,
    'aws_dx_hosted_private_virtual_interface': None,
    'aws_dx_hosted_private_virtual_interface_accepter': None,
    'aws_dx_hosted_public_virtual_interface': None,
    'aws_dx_hosted_public_virtual_interface_accepter': None,
    'aws_dx_hosted_transit_virtual_interface': None,
    'aws_dx_hosted_transit_virtual_interface_accepter': None,
    'aws_dx_lag': None,
    'aws_dx_location': None,
    'aws_dx_locations': None,
    'aws_dx_macsec_key_association': None,
    'aws_dx_private_virtual_interface': None,
    'aws_dx_public_virtual_interface': None,
    'aws_dx_router_configuration': None,
    'aws_dx_transit_virtual_interface': None,
    'aws_dynamodb_contributor_insights': None,
    'aws_dynamodb_global_table': 'aws.database.DynamodbTable',
    'aws_dynamodb_kinesis_streaming_destination': None,
    'aws_dynamodb_resource_policy': 'aws.security.IAMPermissions',
    'aws_dynamodb_table': 'aws.database.DynamodbTable',
    'aws_dynamodb_table_export': None,
    'aws_dynamodb_table_item': None,
    'aws_dynamodb_table_replica': None,
    'aws_dynamodb_tag': None,
    'aws_ebs_default_kms_key': None,
    'aws_ebs_encryption_by_default': None,
    'aws_ebs_fast_snapshot_restore': None,
    'aws_ebs_snapshot': 'aws.storage.ElasticBlockStoreEBSSnapshot',
    'aws_ebs_snapshot_block_public_access': None,
    'aws_ebs_snapshot_copy': None,
    'aws_ebs_snapshot_ids': None,
    'aws_ebs_snapshot_import': None,
    'aws_ebs_volume': 'aws.storage.ElasticBlockStoreEBSVolume',
    'aws_ebs_volumes': 'aws.storage.ElasticBlockStoreEBSVolume',
    'aws_ec2_availability_zone_group': None,
    'aws_ec2_capacity_block_offering': None,
    'aws_ec2_capacity_block_reservation': None,
    'aws_ec2_capacity_reservation': None,
    'aws_ec2_carrier_gateway': None,
    'aws_ec2_client_vpn_authorization_rule': None,
    'aws_ec2_client_vpn_endpoint': 'aws.network.ClientVpn',
    'aws_ec2_client_vpn_network_association': None,
    'aws_ec2_client_vpn_route': None,
    'aws_ec2_coip_pool': None,
    'aws_ec2_coip_pools': None,
    'aws_ec2_fleet': None,
    'aws_ec2_host': None,
    'aws_ec2_image_block_public_access': None,
    'aws_ec2_instance_connect_endpoint': None,
    'aws_ec2_instance_metadata_defaults': None,
    'aws_ec2_instance_state': None,
    'aws_ec2_instance_type': None,
    'aws_ec2_instance_type_offering': None,
    'aws_ec2_instance_type_offerings': None,
    'aws_ec2_instance_types': None,
    'aws_ec2_local_gateway': None,
    'aws_ec2_local_gateway_route': None,
    'aws_ec2_local_gateway_route_table': None,
    'aws_ec2_local_gateway_route_table_vpc_association': None,
    'aws_ec2_local_gateway_route_tables': None,
    'aws_ec2_local_gateway_virtual_interface': None,
    'aws_ec2_local_gateway_virtual_interface_group': None,
    'aws_ec2_local_gateway_virtual_interface_groups': None,
    'aws_ec2_local_gateways': None,
    'aws_ec2_managed_prefix_list': None,
    'aws_ec2_managed_prefix_list_entry': None,
    'aws_ec2_managed_prefix_lists': None,
    'aws_ec2_network_insights_analysis': None,
    'aws_ec2_network_insights_path': None,
    'aws_ec2_public_ipv4_pool': None,
    'aws_ec2_public_ipv4_pools': None,
    'aws_ec2_serial_console_access': None,
    'aws_ec2_spot_price': None,
    'aws_ec2_subnet_cidr_reservation': None,
    'aws_ec2_tag': None,
    'aws_ec2_traffic_mirror_filter': None,
    'aws_ec2_traffic_mirror_filter_rule': None,
    'aws_ec2_traffic_mirror_session': None,
    'aws_ec2_traffic_mirror_target': None,
    'aws_ec2_transit_gateway': 'aws.network.TransitGateway',
    'aws_ec2_transit_gateway_attachment': None,
    'aws_ec2_transit_gateway_attachments': None,
    'aws_ec2_transit_gateway_connect': None,
    'aws_ec2_transit_gateway_connect_peer': None,
    'aws_ec2_transit_gateway_dx_gateway_attachment': None,
    'aws_ec2_transit_gateway_multicast_domain': None,
    'aws_ec2_transit_gateway_multicast_domain_association': None,
    'aws_ec2_transit_gateway_multicast_group_member': None,
    'aws_ec2_transit_gateway_multicast_group_source': None,
    'aws_ec2_transit_gateway_peering_attachment': None,
    'aws_ec2_transit_gateway_peering_attachment_accepter': None,
    'aws_ec2_transit_gateway_peering_attachments': None,
    'aws_ec2_transit_gateway_policy_table': None,
    'aws_ec2_transit_gateway_policy_table_association': None,
    'aws_ec2_transit_gateway_prefix_list_reference': None,
    'aws_ec2_transit_gateway_route': None,
    'aws_ec2_transit_gateway_route_table': None,
    'aws_ec2_transit_gateway_route_table_association': None,
    'aws_ec2_transit_gateway_route_table_associations': None,
    'aws_ec2_transit_gateway_route_table_propagation': None,
    'aws_ec2_transit_gateway_route_table_routes': None,
    'aws_ec2_transit_gateway_route_tables': None,
    'aws_ec2_transit_gateway_vpc_attachment': None,
    'aws_ec2_transit_gateway_vpc_attachment_accepter': None,
    'aws_ec2_transit_gateway_vpc_attachments': None,
    'aws_ec2_transit_gateway_vpn_attachment': None,
    'aws_ec2_transitgateway_route_table_propagations': None,
    'aws_ecr_authorization_token': None,
    'aws_ecr_image': 'aws.compute.EC2ContainerRegistryImage',
    'aws_ecr_lifecycle_policy': None,
    'aws_ecr_lifecycle_policy_document': None,
    'aws_ecr_pull_through_cache_rule': None,
    'aws_ecr_registry_policy': None,
    'aws_ecr_registry_scanning_configuration': None,
    'aws_ecr_replication_configuration': None,
    'aws_ecr_repositories': 'aws.compute.EC2ContainerRegistryRegistry',
    'aws_ecr_repository': 'aws.compute.ECR',
    'aws_ecr_repository_creation_template': None,
    'aws_ecr_repository_policy': 'aws.security.IAMPermissions',
    'aws_ecrpublic_authorization_token': None,
    'aws_ecrpublic_repository': 'aws.compute.ECR',
    'aws_ecrpublic_repository_policy': 'aws.security.IAMPermissions',
    'aws_ecs_account_setting_default': None,
    'aws_ecs_capacity_provider': None,
    'aws_ecs_cluster': 'aws.compute.ElasticContainerService',
    'aws_ecs_cluster_capacity_providers': None,
    'aws_ecs_container_definition': None,
    'aws_ecs_service': 'aws.compute.ECS',
    'aws_ecs_tag': None,
    'aws_ecs_task_definition': None,
    'aws_ecs_task_execution': None,
    'aws_ecs_task_set': None,
    'aws_efs_access_point': None,
    'aws_efs_access_points': None,
    'aws_efs_backup_policy': 'aws.storage.Backup',
    'aws_efs_file_system': 'aws.storage.ElasticFileSystemEFSFileSystem',
    'aws_efs_file_system_policy': None,
    'aws_efs_mount_target': None,
    'aws_efs_replication_configuration': None,
    'aws_egress_only_internet_gateway': None,
    'aws_eip': None,
    'aws_eip_association': None,
    'aws_eip_domain_name': None,
    'aws_eips': None,
    'aws_eks_access_entry': None,
    'aws_eks_access_policy_associattion': None,
    'aws_eks_addon': None,
    'aws_eks_addon_version': None,
    'aws_eks_cluster': 'aws.compute.EKS',
    'aws_eks_cluster_auth': None,
    'aws_eks_clusters': 'aws.compute.EKS',
    'aws_eks_fargate_profile': None,
    'aws_eks_identity_provider_config': None,
    'aws_eks_node_group': None,
    'aws_eks_node_groups': None,
    'aws_eks_pod_identity_association': None,
    'aws_elastic_beanstalk_application': 'aws.compute.ElasticBeanstalkApplication',
    'aws_elastic_beanstalk_application_version': None,
    'aws_elastic_beanstalk_configuration_template': None,
    'aws_elastic_beanstalk_environment': None,
    'aws_elastic_beanstalk_hosted_zone': None,
    'aws_elastic_beanstalk_solution_stack': None,
    'aws_elasticache_cluster': 'aws.database.ElastiCache',
    'aws_elasticache_global_replication_group': None,
    'aws_elasticache_parameter_group': None,
    'aws_elasticache_replication_group': None,
    'aws_elasticache_serverless_cache': None,
    'aws_elasticache_subnet_group': None,
    'aws_elasticache_user': 'aws.general.User',
    'aws_elasticache_user_group': None,
    'aws_elasticache_user_group_association': None,
    'aws_elasticsearch_domain': 'aws.analytics.ES',
    'aws_elasticsearch_domain_policy': 'aws.security.IAMPermissions',
    'aws_elasticsearch_domain_saml_options': None,
    'aws_elasticsearch_vpc_endpoint': None,
    'aws_elastictranscoder_pipeline': 'aws.media.ElasticTranscoder',
    'aws_elastictranscoder_preset': None,
    'aws_elb': 'aws.network.ELB',
    'aws_elb_attachment': None,
    'aws_elb_hosted_zone_id': None,
    'aws_elb_service_account': None,
    'aws_emr_block_public_access_configuration': None,
    'aws_emr_cluster': 'aws.analytics.EMRCluster',
    'aws_emr_instance_fleet': None,
    'aws_emr_instance_group': None,
    'aws_emr_managed_scaling_policy': None,
    'aws_emr_release_labels': None,
    'aws_emr_security_configuration': None,
    'aws_emr_studio': None,
    'aws_emr_studio_session_mapping': None,
    'aws_emr_supported_instance_types': None,
    'aws_emrcontainers_job_template': None,
    'aws_emrcontainers_virtual_cluster': None,
    'aws_emrserverless_application': None,
    'aws_evidently_feature': None,
    'aws_evidently_launch': None,
    'aws_evidently_project': None,
    'aws_evidently_segment': None,
    'aws_finspace_kx_cluster': None,
    'aws_finspace_kx_database': None,
    'aws_finspace_kx_dataview': None,
    'aws_finspace_kx_environment': None,
    'aws_finspace_kx_scaling_group': None,
    'aws_finspace_kx_user': 'aws.general.User',
    'aws_finspace_kx_volume': None,
    'aws_fis_experiment_template': None,
    'aws_flow_log': 'aws.network.VPCFlowLogs',
    'aws_fms_admin_account': None,
    'aws_fms_policy': None,
    'aws_fms_resource_set': None,
    'aws_fsx_backup': 'aws.storage.Backup',
    'aws_fsx_data_repository_association': None,
    'aws_fsx_file_cache': None,
    'aws_fsx_lustre_file_system': 'aws.storage.FsxForLustre',
    'aws_fsx_ontap_file_system': None,
    'aws_fsx_ontap_storage_virtual_machine': None,
    'aws_fsx_ontap_storage_virtual_machines': None,
    'aws_fsx_ontap_volume': None,
    'aws_fsx_openzfs_file_system': None,
    'aws_fsx_openzfs_snapshot': None,
    'aws_fsx_openzfs_volume': None,
    'aws_fsx_windows_file_system': 'aws.storage.FsxForWindowsFileServer',
    'aws_gamelift_alias': None,
    'aws_gamelift_build': None,
    'aws_gamelift_fleet': None,
    'aws_gamelift_game_server_group': 'aws.game.Gamelift',
    'aws_gamelift_game_session_queue': None,
    'aws_gamelift_script': None,
    'aws_glacier_vault': 'aws.storage.S3GlacierVault',
    'aws_glacier_vault_lock': None,
    'aws_globalaccelerator_accelerator': 'aws.network.GlobalAccelerator',
    'aws_globalaccelerator_cross_account_attachment': None,
    'aws_globalaccelerator_custom_routing_accelerator': None,
    'aws_globalaccelerator_custom_routing_endpoint_group': None,
    'aws_globalaccelerator_custom_routing_listener': None,
    'aws_globalaccelerator_endpoint_group': None,
    'aws_globalaccelerator_listener': None,
    'aws_glue_catalog_database': 'aws.analytics.GlueDataCatalog',
    'aws_glue_catalog_table': None,
    'aws_glue_classifier': None,
    'aws_glue_connection': None,
    'aws_glue_crawler': 'aws.analytics.GlueCrawlers',
    'aws_glue_data_catalog_encryption_settings': None,
    'aws_glue_data_quality_ruleset': None,
    'aws_glue_dev_endpoint': None,
    'aws_glue_job': None,
    'aws_glue_ml_transform': None,
    'aws_glue_partition': None,
    'aws_glue_partition_index': None,
    'aws_glue_registry': None,
    'aws_glue_resource_policy': 'aws.security.IAMPermissions',
    'aws_glue_schema': None,
    'aws_glue_script': 'aws.analytics.Glue',
    'aws_glue_security_configuration': None,
    'aws_glue_trigger': None,
    'aws_glue_user_defined_function': None,
    'aws_glue_workflow': None,
    'aws_grafana_license_association': None,
    'aws_grafana_role_association': None,
    'aws_grafana_workspace': None,
    'aws_grafana_workspace_api_key': None,
    'aws_grafana_workspace_saml_configuration': None,
    'aws_grafana_workspace_service_account': None,
    'aws_grafana_workspace_service_account_token': None,
    'aws_guardduty_detector': 'aws.security.Guardduty',
    'aws_guardduty_detector_feature': None,
    'aws_guardduty_filter': None,
    'aws_guardduty_finding_ids': None,
    'aws_guardduty_invite_accepter': None,
    'aws_guardduty_ipset': None,
    'aws_guardduty_malware_protection_plan': None,
    'aws_guardduty_member': None,
    'aws_guardduty_organization_admin_account': None,
    'aws_guardduty_organization_configuration': None,
    'aws_guardduty_organization_configuration_feature': None,
    'aws_guardduty_publishing_destination': None,
    'aws_guardduty_threatintelset': None,
    'aws_iam_access_key': None,
    'aws_iam_access_keys': None,
    'aws_iam_account_alias': None,
    'aws_iam_account_password_policy': None,
    'aws_iam_group': 'aws.general.Users',
    'aws_iam_group_membership': None,
    'aws_iam_group_policy': 'aws.security.IAMPermissions',
    'aws_iam_group_policy_attachment': None,
    'aws_iam_instance_profile': None,
    'aws_iam_instance_profiles': None,
    'aws_iam_openid_connect_provider': None,
    'aws_iam_policy': 'aws.security.IAMPermissions',
    'aws_iam_policy_attachment': None,
    'aws_iam_policy_document': None,
    'aws_iam_principal_policy_simulation': None,
    'aws_iam_role': 'aws.security.IAMRole',
    'aws_iam_role_policy': 'aws.security.IAMPermissions',
    'aws_iam_role_policy_attachment': None,
    'aws_iam_roles': None,
    'aws_iam_saml_provider': None,
    'aws_iam_security_token_service_preferences': None,
    'aws_iam_server_certificate': None,
    'aws_iam_service_linked_role': None,
    'aws_iam_service_specific_credential': None,
    'aws_iam_session_context': None,
    'aws_iam_signing_certificate': None,
    'aws_iam_user': 'aws.general.User',
    'aws_iam_user_group_membership': None,
    'aws_iam_user_login_profile': None,
    'aws_iam_user_policy': 'aws.security.IAMPermissions',
    'aws_iam_user_policy_attachment': None,
    'aws_iam_user_ssh_key': None,
    'aws_iam_users': 'aws.general.Users',
    'aws_iam_virtual_mfa_device': None,
    'aws_identitystore_group': 'aws.general.Users',
    'aws_identitystore_group_membership': 'aws.general.User',
    'aws_identitystore_groups': 'aws.general.Users',
    'aws_identitystore_user': 'aws.general.User',
    'aws_imagebuilder_component': None,
    'aws_imagebuilder_components': None,
    'aws_imagebuilder_container_recipe': None,
    'aws_imagebuilder_container_recipes': None,
    'aws_imagebuilder_distribution_configuration': None,
    'aws_imagebuilder_distribution_configurations': None,
    'aws_imagebuilder_image': None,
    'aws_imagebuilder_image_pipeline': None,
    'aws_imagebuilder_image_pipelines': None,
    'aws_imagebuilder_image_recipe': None,
    'aws_imagebuilder_image_recipes': None,
    'aws_imagebuilder_infrastructure_configuration': None,
    'aws_imagebuilder_infrastructure_configurations': None,
    'aws_imagebuilder_workflow': None,
    'aws_inspector_assessment_target': None,
    'aws_inspector_assessment_template': None,
    'aws_inspector_resource_group': None,
    'aws_inspector_rules_packages': None,
    'aws_inspector2_delegated_admin_account': None,
    'aws_inspector2_enabler': 'aws.security.Inspector',
    'aws_inspector2_member_association': None,
    'aws_inspector2_organization_configuration': None,
    'aws_instance': 'aws.compute.EC2Instance',
    'aws_instances': 'aws.compute.EC2Instances',
    'aws_internet_gateway': 'aws.network.InternetGateway',
    'aws_internet_gateway_attachment': None,
    'aws_internetmonitor_monitor': None,
    'aws_iot_authorizer': None,
    'aws_iot_billing_group': None,
    'aws_iot_ca_certificate': None,
    'aws_iot_certificate': 'aws.iot.IotCertificate',
    'aws_iot_domain_configuration': None,
    'aws_iot_endpoint': None,
    'aws_iot_event_configurations': None,
    'aws_iot_indexing_configuration': None,
    'aws_iot_logging_options': None,
    'aws_iot_policy': 'aws.iot.IotPolicy',
    'aws_iot_policy_attachment': None,
    'aws_iot_provisioning_template': None,
    'aws_iot_registration_code': None,
    'aws_iot_role_alias': None,
    'aws_iot_thing': 'aws.iot.InternetOfThings',
    'aws_iot_thing_group': None,
    'aws_iot_thing_group_membership': None,
    'aws_iot_thing_principal_attachment': None,
    'aws_iot_thing_type': None,
    'aws_iot_topic_rule': None,
    'aws_iot_topic_rule_destination': None,
    'aws_ip_ranges': None,
    'aws_ivs_channel': None,
    'aws_ivs_playback_key_pair': None,
    'aws_ivs_recording_configuration': None,
    'aws_ivs_stream_key': None,
    'aws_ivschat_logging_configuration': None,
    'aws_ivschat_room': None,
    'aws_kendra_data_source': None,
    'aws_kendra_experience': None,
    'aws_kendra_faq': None,
    'aws_kendra_index': 'aws.ml.Kendra',
    'aws_kendra_query_suggestions_block_list': None,
    'aws_kendra_thesaurus': None,
    'aws_key_pair': None,
    'aws_keyspaces_keyspace': None,
    'aws_keyspaces_table': None,
    'aws_kinesis_analytics_application': 'aws.analytics.KinesisDataAnalytics',
    'aws_kinesis_firehose_delivery_stream': 'aws.analytics.KinesisDataFirehose',
    'aws_kinesis_resource_policy': 'aws.security.IAMPermissions',
    'aws_kinesis_stream': 'aws.analytics.KinesisDataStreams',
    'aws_kinesis_stream_consumer': None,
    'aws_kinesis_video_stream': 'aws.media.KinesisVideoStreams',
    'aws_kinesisanalyticsv2_application': 'aws.analytics.KinesisDataAnalytics',
    'aws_kinesisanalyticsv2_application_snapshot': None,
    'aws_kms_alias': 'aws.security.KMS',
    'aws_kms_ciphertext': None,
    'aws_kms_custom_key_store': None,
    'aws_kms_external_key': None,
    'aws_kms_grant': None,
    'aws_kms_key': 'aws.security.KMS',
    'aws_kms_key_policy': 'aws.security.IAMPermissions',
    'aws_kms_public_key': None,
    'aws_kms_replica_external_key': None,
    'aws_kms_replica_key': None,
    'aws_kms_secret': None,
    'aws_kms_secrets': None,
    'aws_lakeformation_data_cells_filter': None,
    'aws_lakeformation_data_lake_settings': None,
    'aws_lakeformation_lf_tag': None,
    'aws_lakeformation_permissions': None,
    'aws_lakeformation_resource': 'aws.analytics.LakeFormation',
    'aws_lakeformation_resource_lf_tag': None,
    'aws_lakeformation_resource_lf_tags': None,
    'aws_lambda_alias': None,
    'aws_lambda_code_signing_config': None,
    'aws_lambda_event_source_mapping': None,
    'aws_lambda_function': 'aws.compute.LambdaFunction',
    'aws_lambda_function_event_invoke_config': None,
    'aws_lambda_function_url': None,
    'aws_lambda_functions': 'aws.compute.Lambda',
    'aws_lambda_invocation': None,
    'aws_lambda_layer_version': None,
    'aws_lambda_layer_version_permission': None,
    'aws_lambda_permission': None,
    'aws_lambda_provisioned_concurrency_config': None,
    'aws_lambda_runtime_management_config': None,
    'aws_launch_configuration': None,
    'aws_launch_template': None,
    'aws_lb': 'aws.network.ELB',
    'aws_lb_cookie_stickiness_policy': None,
    'aws_lb_hosted_zone_id': None,
    'aws_lb_listener': None,
    'aws_lb_listener_certificate': None,
    'aws_lb_listener_rule': None,
    'aws_lb_ssl_negotiation_policy': None,
    'aws_lb_target_group': None,
    'aws_lb_target_group_attachment': None,
    'aws_lb_trust_store': None,
    'aws_lb_trust_store_revocation': None,
    'aws_lbs': 'aws.network.ELB',
    'aws_lex_bot': 'aws.ml.Lex',
    'aws_lex_bot_alias': None,
    'aws_lex_intent': None,
    'aws_lex_slot_type': None,
    'aws_lexv2models_bot': 'aws.ml.Lex',
    'aws_lexv2models_bot_locale': None,
    'aws_lexv2models_bot_version': None,
    'aws_lexv2models_intent': None,
    'aws_lexv2models_slot': None,
    'aws_lexv2models_slot_type': None,
    'aws_licensemanager_association': None,
    'aws_licensemanager_grant': None,
    'aws_licensemanager_grant_accepter': None,
    'aws_licensemanager_grants': None,
    'aws_licensemanager_license_configuration': 'aws.management.LicenseManager',
    'aws_licensemanager_received_license': None,
    'aws_licensemanager_received_licenses': None,
    'aws_lightsail_bucket': None,
    'aws_lightsail_bucket_access_key': None,
    'aws_lightsail_bucket_resource_access': None,
    'aws_lightsail_certificate': None,
    'aws_lightsail_container_service': 'aws.compute.Lightsail',
    'aws_lightsail_container_service_deployment_version': None,
    'aws_lightsail_database': None,
    'aws_lightsail_disk': None,
    'aws_lightsail_disk_attachment': None,
    'aws_lightsail_distribution': None,
    'aws_lightsail_domain': None,
    'aws_lightsail_domain_entry': None,
    'aws_lightsail_instance': 'aws.compute.Lightsail',
    'aws_lightsail_instance_public_ports': None,
    'aws_lightsail_key_pair': None,
    'aws_lightsail_lb': None,
    'aws_lightsail_lb_attachment': None,
    'aws_lightsail_lb_certificate': None,
    'aws_lightsail_lb_certificate_attachment': None,
    'aws_lightsail_lb_https_redirection_policy': None,
    'aws_lightsail_lb_stickiness_policy': None,
    'aws_lightsail_static_ip': None,
    'aws_lightsail_static_ip_attachment': None,
    'aws_load_balancer_backend_server_policy': None,
    'aws_load_balancer_listener_policy': None,
    'aws_load_balancer_policy': None,
    'aws_location_geofence_collection': None,
    'aws_location_map': None,
    'aws_location_place_index': None,
    'aws_location_route_calculator': None,
    'aws_location_tracker': None,
    'aws_location_tracker_association': None,
    'aws_location_tracker_associations': None,
    'aws_m2_application': None,
    'aws_m2_deployment': None,
    'aws_m2_environment': None,
    'aws_macie2_account': 'aws.security.Macie',
    'aws_macie2_classification_export_configuration': None,
    'aws_macie2_classification_job': None,
    'aws_macie2_custom_data_identifier': None,
    'aws_macie2_findings_filter': None,
    'aws_macie2_invitation_accepter': None,
    'aws_macie2_member': None,
    'aws_macie2_organization_admin_account': None,
    'aws_main_route_table_association': None,
    'aws_media_convert_queue': None,
    'aws_media_package_channel': None,
    'aws_media_store_container': None,
    'aws_media_store_container_policy': None,
    'aws_medialive_channel': None,
    'aws_medialive_input': None,
    'aws_medialive_input_security_group': None,
    'aws_medialive_multiplex': None,
    'aws_medialive_multiplex_program': None,
    'aws_memorydb_acl': None,
    'aws_memorydb_cluster': None,
    'aws_memorydb_parameter_group': None,
    'aws_memorydb_snapshot': None,
    'aws_memorydb_subnet_group': None,
    'aws_memorydb_user': 'aws.general.User',
    'aws_mq_broker': None,
    'aws_mq_broker_engine_types': None,
    'aws_mq_broker_instance_type_offerings': None,
    'aws_mq_configuration': None,
    'aws_msk_bootstrap_brokers': None,
    'aws_msk_broker_nodes': None,
    'aws_msk_cluster': None,
    'aws_msk_cluster_policy': None,
    'aws_msk_configuration': None,
    'aws_msk_kafka_version': None,
    'aws_msk_replicator': None,
    'aws_msk_scram_secret_association': None,
    'aws_msk_serverless_cluster': None,
    'aws_msk_vpc_connection': None,
    'aws_mskconnect_connector': None,
    'aws_mskconnect_custom_plugin': None,
    'aws_mskconnect_worker_configuration': None,
    'aws_mwaa_environment': None,
    'aws_nat_gateway': 'aws.network.NATGateway',
    'aws_nat_gateways': 'aws.network.NATGateway',
    'aws_neptune_cluster': 'aws.database.Neptune',
    'aws_neptune_cluster_endpoint': None,
    'aws_neptune_cluster_instance': None,
    'aws_neptune_cluster_parameter_group': None,
    'aws_neptune_cluster_snapshot': None,
    'aws_neptune_engine_version': None,
    'aws_neptune_event_subscription': None,
    'aws_neptune_global_cluster': None,
    'aws_neptune_orderable_db_instance': None,
    'aws_neptune_parameter_group': None,
    'aws_neptune_subnet_group': None,
    'aws_network_acl': None,
    'aws_network_acl_association': None,
    'aws_network_acl_rule': None,
    'aws_network_acls': 'aws.network.Nacl',
    'aws_network_interface': None,
    'aws_network_interface_attachment': None,
    'aws_network_interface_sg_attachment': None,
    'aws_network_interfaces': None,
    'aws_networkfirewall_firewall': None,
    'aws_networkfirewall_firewall_policy': None,
    'aws_networkfirewall_logging_configuration': None,
    'aws_networkfirewall_resource_policy': None,
    'aws_networkfirewall_rule_group': None,
    'aws_networkfirewall_tls_inspection_configuration': None,
    'aws_networkmanager_attachment_accepter': None,
    'aws_networkmanager_connect_attachment': None,
    'aws_networkmanager_connect_peer': None,
    'aws_networkmanager_connection': None,
    'aws_networkmanager_connections': None,
    'aws_networkmanager_core_network': None,
    'aws_networkmanager_core_network_policy_attachment': None,
    'aws_networkmanager_core_network_policy_document': None,
    'aws_networkmanager_customer_gateway_association': None,
    'aws_networkmanager_device': None,
    'aws_networkmanager_devices': None,
    'aws_networkmanager_global_network': None,
    'aws_networkmanager_global_networks': None,
    'aws_networkmanager_link': None,
    'aws_networkmanager_link_association': None,
    'aws_networkmanager_links': None,
    'aws_networkmanager_site': None,
    'aws_networkmanager_site_to_site_vpn_attachment': None,
    'aws_networkmanager_sites': None,
    'aws_networkmanager_transit_gateway_connect_peer_association': None,
    'aws_networkmanager_transit_gateway_peering': None,
    'aws_networkmanager_transit_gateway_registration': None,
    'aws_networkmanager_transit_gateway_route_table_attachment': None,
    'aws_networkmanager_vpc_attachment': None,
    'aws_networkmonitor_monitor': None,
    'aws_networkmonitor_probe': None,
    'aws_oam_link': None,
    'aws_oam_links': None,
    'aws_oam_sink': None,
    'aws_oam_sink_policy': None,
    'aws_oam_sinks': None,
    'aws_opensearch_domain': 'aws.analytics.ES',
    'aws_opensearch_domain_policy': 'aws.security.IAMPermissions',
    'aws_opensearch_domain_saml_options': None,
    'aws_opensearch_inbound_connection_accepter': None,
    'aws_opensearch_outbound_connection': None,
    'aws_opensearch_package': None,
    'aws_opensearch_package_association': None,
    'aws_opensearch_vpc_endpoint': None,
    'aws_opensearchserverless_access_policy': 'aws.security.IAMPermissions',
    'aws_opensearchserverless_collection': None,
    'aws_opensearchserverless_lifecycle_policy': None,
    'aws_opensearchserverless_security_config': None,
    'aws_opensearchserverless_security_policy': 'aws.security.IAMPermissions',
    'aws_opensearchserverless_vpc_endpoint': None,
    'aws_opsworks_application': 'aws.management.OpsworksApps',
    'aws_opsworks_custom_layer': 'aws.management.OpsworksLayers',
    'aws_opsworks_ecs_cluster_layer': None,
    'aws_opsworks_ganglia_layer': None,
    'aws_opsworks_haproxy_layer': None,
    'aws_opsworks_instance': None,
    'aws_opsworks_java_app_layer': None,
    'aws_opsworks_memcached_layer': None,
    'aws_opsworks_mysql_layer': None,
    'aws_opsworks_nodejs_app_layer': None,
    'aws_opsworks_permission': 'aws.management.OpsworksPermissions',
    'aws_opsworks_php_app_layer': None,
    'aws_opsworks_rails_app_layer': None,
    'aws_opsworks_rds_db_instance': None,
    'aws_opsworks_stack': 'aws.management.OpsworksStack',
    'aws_opsworks_static_web_layer': None,
    'aws_opsworks_user_profile': None,
    'aws_organizations_account': 'aws.management.OrganizationsAccount',
    'aws_organizations_delegated_administrator': None,
    'aws_organizations_delegated_administrators': None,
    'aws_organizations_delegated_services': None,
    'aws_organizations_organization': 'aws.management.Organization',
    'aws_organizations_organizational_unit': 'aws.management.OrganizationsOrganizationalUnit',
    'aws_organizations_organizational_unit_child_accounts': None,
    'aws_organizations_organizational_unit_descendant_accounts': None,
    'aws_organizations_organizational_units': 'aws.management.OrganizationsOrganizationalUnit',
    'aws_organizations_policies': None,
    'aws_organizations_policies_for_target': None,
    'aws_organizations_policy': None,
    'aws_organizations_policy_attachment': None,
    'aws_organizations_resource_policy': None,
    'aws_organizations_resource_tags': None,
    'aws_osis_pipeline': None,
    'aws_outposts_asset': None,
    'aws_outposts_assets': None,
    'aws_outposts_outpost': 'aws.compute.Outposts',
    'aws_outposts_outpost_instance_type': None,
    'aws_outposts_outpost_instance_types': None,
    'aws_outposts_outposts': 'aws.compute.Outposts',
    'aws_outposts_site': None,
    'aws_outposts_sites': None,
    'aws_partition': None,
    'aws_paymentcryptography_key': None,
    'aws_paymentcryptography_key_alias': None,
    'aws_pinpoint_adm_channel': None,
    'aws_pinpoint_apns_channel': None,
    'aws_pinpoint_apns_sandbox_channel': None,
    'aws_pinpoint_apns_voip_channel': None,
    'aws_pinpoint_apns_voip_sandbox_channel': None,
    'aws_pinpoint_app': 'aws.mobile.Pinpoint',
    'aws_pinpoint_baidu_channel': None,
    'aws_pinpoint_email_channel': None,
    'aws_pinpoint_email_template': None,
    'aws_pinpoint_event_stream': None,
    'aws_pinpoint_gcm_channel': None,
    'aws_pinpoint_sms_channel': None,
    'aws_pipes_pipe': None,
    'aws_placement_group': None,
    'aws_polly_voices': 'aws.ml.Polly',
    'aws_prefix_list': None,
    'aws_pricing_product': None,
    'aws_prometheus_alert_manager_definition': None,
    'aws_prometheus_rule_group_namespace': None,
    'aws_prometheus_scraper': None,
    'aws_prometheus_workspace': None,
    'aws_prometheus_workspaces': None,
    'aws_proxy_protocol_policy': None,
    'aws_qldb_ledger': None,
    'aws_qldb_stream': None,
    'aws_quicksight_account_subscription': None,
    'aws_quicksight_analysis': None,
    'aws_quicksight_dashboard': 'aws.analytics.Quicksight',
    'aws_quicksight_data_set': None,
    'aws_quicksight_data_source': None,
    'aws_quicksight_folder': None,
    'aws_quicksight_folder_membership': None,
    'aws_quicksight_group': 'aws.general.Users',
    'aws_quicksight_group_membership': 'aws.general.User',
    'aws_quicksight_iam_policy_assignment': None,
    'aws_quicksight_ingestion': None,
    'aws_quicksight_namespace': None,
    'aws_quicksight_refresh_schedule': None,
    'aws_quicksight_template': None,
    'aws_quicksight_template_alias': None,
    'aws_quicksight_theme': None,
    'aws_quicksight_user': 'aws.general.User',
    'aws_quicksight_vpc_connection': None,
    'aws_ram_principal_association': None,
    'aws_ram_resource_association': None,
    'aws_ram_resource_share': 'aws.security.RAM',
    'aws_ram_resource_share_accepter': None,
    'aws_ram_sharing_with_organization': None,
    'aws_rbin_rule': None,
    'aws_rds_certificate': None,
    'aws_rds_cluster': 'aws.database.DB',
    'aws_rds_cluster_activity_stream': None,
    'aws_rds_cluster_endpoint': None,
    'aws_rds_cluster_instance': 'aws.database.RDSInstance',
    'aws_rds_cluster_parameter_group': None,
    'aws_rds_cluster_role_association': None,
    'aws_rds_clusters': 'aws.database.DB',
    'aws_rds_custom_db_engine_version': None,
    'aws_rds_engine_version': None,
    'aws_rds_export_task': None,
    'aws_rds_global_cluster': 'aws.database.DB',
    'aws_rds_integration': None,
    'aws_rds_orderable_db_instance': 'aws.database.RDSInstance',
    'aws_rds_reserved_instance': 'aws.database.RDSInstance',
    'aws_rds_reserved_instance_offering': None,
    'aws_redshift_authentication_profile': None,
    'aws_redshift_cluster': 'aws.database.Redshift',
    'aws_redshift_cluster_credentials': None,
    'aws_redshift_cluster_iam_roles': None,
    'aws_redshift_cluster_snapshot': None,
    'aws_redshift_data_share_authorization': None,
    'aws_redshift_data_share_consumer_association': None,
    'aws_redshift_data_shares': None,
    'aws_redshift_endpoint_access': None,
    'aws_redshift_endpoint_authorization': None,
    'aws_redshift_event_subscription': None,
    'aws_redshift_hsm_client_certificate': None,
    'aws_redshift_hsm_configuration': None,
    'aws_redshift_logging': None,
    'aws_redshift_orderable_cluster': None,
    'aws_redshift_parameter_group': None,
    'aws_redshift_partner': None,
    'aws_redshift_producer_data_shares': None,
    'aws_redshift_resource_policy': 'aws.security.IAMPermissions',
    'aws_redshift_scheduled_action': None,
    'aws_redshift_service_account': None,
    'aws_redshift_snapshot_copy': None,
    'aws_redshift_snapshot_copy_grant': None,
    'aws_redshift_snapshot_schedule': None,
    'aws_redshift_snapshot_schedule_association': None,
    'aws_redshift_subnet_group': None,
    'aws_redshift_usage_limit': None,
    'aws_redshiftdata_statement': None,
    'aws_redshiftserverless_credentials': None,
    'aws_redshiftserverless_custom_domain_association': None,
    'aws_redshiftserverless_endpoint_access': None,
    'aws_redshiftserverless_namespace': None,
    'aws_redshiftserverless_resource_policy': 'aws.security.IAMPermissions',
    'aws_redshiftserverless_snapshot': None,
    'aws_redshiftserverless_usage_limit': None,
    'aws_redshiftserverless_workgroup': None,
    'aws_region': None,
    'aws_regions': None,
    'aws_rekognition_collection': None,
    'aws_rekognition_project': 'aws.ml.Rekognition',
    'aws_rekognition_stream_processor': None,
    'aws_resourceexplorer2_index': None,
    'aws_resourceexplorer2_search': None,
    'aws_resourceexplorer2_view': None,
    'aws_resourcegroups_group': None,
    'aws_resourcegroups_resource': None,
    'aws_resourcegroupstaggingapi_resources': None,
    'aws_rolesanywhere_profile': None,
    'aws_rolesanywhere_trust_anchor': None,
    'aws_route': 'aws.network.VPCRouter',
    'aws_route_table': 'aws.network.RouteTable',
    'aws_route_table_association': None,
    'aws_route_tables': 'aws.network.RouteTable',
    'aws_route53_cidr_collection': None,
    'aws_route53_cidr_location': None,
    'aws_route53_delegation_set': None,
    'aws_route53_health_check': None,
    'aws_route53_hosted_zone_dnssec': None,
    'aws_route53_key_signing_key': None,
    'aws_route53_query_log': None,
    'aws_route53_record': None,
    'aws_route53_resolver_config': None,
    'aws_route53_resolver_dnssec_config': None,
    'aws_route53_resolver_endpoint': None,
    'aws_route53_resolver_firewall_config': None,
    'aws_route53_resolver_firewall_domain_list': None,
    'aws_route53_resolver_firewall_rule': None,
    'aws_route53_resolver_firewall_rule_group': None,
    'aws_route53_resolver_firewall_rule_group_association': None,
    'aws_route53_resolver_firewall_rules': None,
    'aws_route53_resolver_query_log_config': None,
    'aws_route53_resolver_query_log_config_association': None,
    'aws_route53_resolver_rule': None,
    'aws_route53_resolver_rule_association': None,
    'aws_route53_resolver_rules': None,
    'aws_route53_traffic_policy': None,
    'aws_route53_traffic_policy_document': None,
    'aws_route53_traffic_policy_instance': None,
    'aws_route53_vpc_association_authorization': None,
    'aws_route53_zone': 'aws.network.Route53HostedZone',
    'aws_route53_zone_association': None,
    'aws_route53domains_delegation_signer_record': None,
    'aws_route53domains_registered_domain': None,
    'aws_route53recoverycontrolconfig_cluster': None,
    'aws_route53recoverycontrolconfig_control_panel': None,
    'aws_route53recoverycontrolconfig_routing_control': None,
    'aws_route53recoverycontrolconfig_safety_rule': None,
    'aws_route53recoveryreadiness_cell': None,
    'aws_route53recoveryreadiness_readiness_check': None,
    'aws_route53recoveryreadiness_recovery_group': None,
    'aws_route53recoveryreadiness_resource_set': None,
    'aws_rum_app_monitor': None,
    'aws_rum_metrics_destination': None,
    'aws_s3_access_point': None,
    'aws_s3_account_public_access_block': None,
    'aws_s3_bucket': 'aws.storage.S3',
    'aws_s3_bucket_accelerate_configuration': None,
    'aws_s3_bucket_acl': None,
    'aws_s3_bucket_analytics_configuration': None,
    'aws_s3_bucket_cors_configuration': None,
    'aws_s3_bucket_intelligent_tiering_configuration': None,
    'aws_s3_bucket_inventory': None,
    'aws_s3_bucket_lifecycle_configuration': None,
    'aws_s3_bucket_logging': None,
    'aws_s3_bucket_metric': None,
    'aws_s3_bucket_notification': None,
    'aws_s3_bucket_object': 'aws.storage.SimpleStorageServiceS3Object',
    'aws_s3_bucket_object_lock_configuration': None,
    'aws_s3_bucket_objects': 'aws.storage.SimpleStorageServiceS3Object',
    'aws_s3_bucket_ownership_controls': None,
    'aws_s3_bucket_policy': 'aws.security.IAMPermissions',
    'aws_s3_bucket_public_access_block': None,
    'aws_s3_bucket_replication_configuration': None,
    'aws_s3_bucket_request_payment_configuration': None,
    'aws_s3_bucket_server_side_encryption_configuration': None,
    'aws_s3_bucket_versioning': None,
    'aws_s3_bucket_website_configuration': None,
    'aws_s3_directory_bucket': None,
    'aws_s3_directory_buckets': None,
    'aws_s3_object': None,
    'aws_s3_object_copy': None,
    'aws_s3_objects': None,
    'aws_s3control_access_grant': None,
    'aws_s3control_access_grants_instance': None,
    'aws_s3control_access_grants_instance_resource_policy': None,
    'aws_s3control_access_grants_location': None,
    'aws_s3control_access_point_policy': 'aws.security.IAMPermissions',
    'aws_s3control_bucket': None,
    'aws_s3control_bucket_lifecycle_configuration': None,
    'aws_s3control_bucket_policy': 'aws.security.IAMPermissions',
    'aws_s3control_multi_region_access_point': None,
    'aws_s3control_multi_region_access_point_policy': 'aws.security.IAMPermissions',
    'aws_s3control_object_lambda_access_point': None,
    'aws_s3control_object_lambda_access_point_policy': 'aws.security.IAMPermissions',
    'aws_s3control_storage_lens_configuration': None,
    'aws_s3outposts_endpoint': None,
    'aws_sagemaker_app': None,
    'aws_sagemaker_app_image_config': None,
    'aws_sagemaker_code_repository': None,
    'aws_sagemaker_data_quality_job_definition': None,
    'aws_sagemaker_device': None,
    'aws_sagemaker_device_fleet': None,
    'aws_sagemaker_domain': None,
    'aws_sagemaker_endpoint': None,
    'aws_sagemaker_endpoint_configuration': None,
    'aws_sagemaker_feature_group': None,
    'aws_sagemaker_flow_definition': None,
    'aws_sagemaker_human_task_ui': None,
    'aws_sagemaker_image': None,
    'aws_sagemaker_image_version': None,
    'aws_sagemaker_model': 'aws.ml.SagemakerModel',
    'aws_sagemaker_model_package_group': None,
    'aws_sagemaker_model_package_group_policy': None,
    'aws_sagemaker_monitoring_schedule': None,
    'aws_sagemaker_notebook_instance': 'aws.ml.SagemakerNotebook',
    'aws_sagemaker_notebook_instance_lifecycle_configuration': None,
    'aws_sagemaker_pipeline': None,
    'aws_sagemaker_prebuilt_ecr_image': None,
    'aws_sagemaker_project': 'aws.ml.Sagemaker',
    'aws_sagemaker_servicecatalog_portfolio_status': None,
    'aws_sagemaker_space': None,
    'aws_sagemaker_studio_lifecycle_config': None,
    'aws_sagemaker_user_profile': None,
    'aws_sagemaker_workforce': None,
    'aws_sagemaker_workteam': None,
    'aws_saml_provider': None,
    'aws_scheduler_schedule': None,
    'aws_scheduler_schedule_group': None,
    'aws_schemas_discoverer': None,
    'aws_schemas_registry': None,
    'aws_schemas_registry_policy': None,
    'aws_schemas_schema': None,
    'aws_secretsmanager_random_password': None,
    'aws_secretsmanager_secret': 'aws.security.SecretsManager',
    'aws_secretsmanager_secret_policy': None,
    'aws_secretsmanager_secret_rotation': None,
    'aws_secretsmanager_secret_version': None,
    'aws_secretsmanager_secret_versions': None,
    'aws_secretsmanager_secrets': 'aws.security.SecretsManager',
    'aws_security_group': None,
    'aws_security_group_rule': None,
    'aws_security_groups': None,
    'aws_securityhub_account': 'aws.security.SecurityHub',
    'aws_securityhub_action_target': None,
    'aws_securityhub_automation_rule': None,
    'aws_securityhub_configuration_policy': None,
    'aws_securityhub_configuration_policy_association': None,
    'aws_securityhub_finding_aggregator': None,
    'aws_securityhub_insight': None,
    'aws_securityhub_invite_accepter': None,
    'aws_securityhub_member': None,
    'aws_securityhub_organization_admin_account': None,
    'aws_securityhub_organization_configuration': None,
    'aws_securityhub_product_subscription': None,
    'aws_securityhub_standards_control': None,
    'aws_securityhub_standards_subscription': None,
    'aws_securitylake_aws_log_source': None,
    'aws_securitylake_custom_log_source': None,
    'aws_securitylake_data_lake': None,
    'aws_securitylake_subscriber': None,
    'aws_securitylake_subscriber_notification': None,
    'aws_serverlessapplicationrepository_application': 'aws.compute.SAR',
    'aws_serverlessapplicationrepository_cloudformation_stack': None,
    'aws_service': None,
    'aws_service_discovery_dns_namespace': None,
    'aws_service_discovery_http_namespace': None,
    'aws_service_discovery_instance': None,
    'aws_service_discovery_private_dns_namespace': None,
    'aws_service_discovery_public_dns_namespace': None,
    'aws_service_discovery_service': None,
    'aws_service_principal': None,
    'aws_servicecatalog_budget_resource_association': None,
    'aws_servicecatalog_constraint': None,
    'aws_servicecatalog_launch_paths': None,
    'aws_servicecatalog_organizations_access': None,
    'aws_servicecatalog_portfolio': None,
    'aws_servicecatalog_portfolio_constraints': None,
    'aws_servicecatalog_portfolio_share': None,
    'aws_servicecatalog_principal_portfolio_association': None,
    'aws_servicecatalog_product': 'aws.management.ServiceCatalog',
    'aws_servicecatalog_product_portfolio_association': None,
    'aws_servicecatalog_provisioned_product': None,
    'aws_servicecatalog_provisioning_artifact': None,
    'aws_servicecatalog_provisioning_artifacts': None,
    'aws_servicecatalog_service_action': None,
    'aws_servicecatalog_tag_option': None,
    'aws_servicecatalog_tag_option_resource_association': None,
    'aws_servicecatalogappregistry_application': None,
    'aws_servicequotas_service': None,
    'aws_servicequotas_service_quota': None,
    'aws_servicequotas_template': None,
    'aws_servicequotas_template_association': None,
    'aws_servicequotas_templates': None,
    'aws_ses_active_receipt_rule_set': None,
    'aws_ses_configuration_set': None,
    'aws_ses_domain_dkim': None,
    'aws_ses_domain_identity': None,
    'aws_ses_domain_identity_verification': None,
    'aws_ses_domain_mail_from': None,
    'aws_ses_email_identity': 'aws.engagement.SimpleEmailServiceSesEmail',
    'aws_ses_event_destination': None,
    'aws_ses_identity_notification_topic': None,
    'aws_ses_identity_policy': None,
    'aws_ses_receipt_filter': None,
    'aws_ses_receipt_rule': None,
    'aws_ses_receipt_rule_set': None,
    'aws_ses_template': None,
    'aws_sesv2_account_vdm_attributes': None,
    'aws_sesv2_configuration_set': None,
    'aws_sesv2_configuration_set_event_destination': None,
    'aws_sesv2_contact_list': None,
    'aws_sesv2_dedicated_ip_assignment': None,
    'aws_sesv2_dedicated_ip_pool': None,
    'aws_sesv2_email_identity': 'aws.engagement.SimpleEmailServiceSesEmail',
    'aws_sesv2_email_identity_feedback_attributes': None,
    'aws_sesv2_email_identity_mail_from_attributes': None,
    'aws_sesv2_email_identity_policy': None,
    'aws_sfn_activity': None,
    'aws_sfn_alias': None,
    'aws_sfn_state_machine': 'aws.integration.SF',
    'aws_sfn_state_machine_versions': None,
    'aws_shield_application_layer_automatic_response': None,
    'aws_shield_drt_access_log_bucket_association': None,
    'aws_shield_drt_access_role_arn_association': None,
    'aws_shield_proactive_engagement': None,
    'aws_shield_protection': 'aws.security.Shield',
    'aws_shield_protection_group': None,
    'aws_shield_protection_health_check_association': None,
    'aws_shield_subscription': 'aws.security.ShieldAdvanced',
    'aws_signer_signing_job': None,
    'aws_signer_signing_profile': None,
    'aws_signer_signing_profile_permission': None,
    'aws_simpledb_domain': None,
    'aws_snapshot_create_volume_permission': None,
    'aws_sns_platform_application': None,
    'aws_sns_sms_preferences': None,
    'aws_sns_topic': 'aws.integration.SNS',
    'aws_sns_topic_data_protection_policy': None,
    'aws_sns_topic_policy': 'aws.security.IAMPermissions',
    'aws_sns_topic_subscription': None,
    'aws_spot_datafeed_subscription': None,
    'aws_spot_fleet_request': None,
    'aws_spot_instance_request': None,
    'aws_sqs_queue': 'aws.integration.SQS',
    'aws_sqs_queue_policy': 'aws.security.IAMPermissions',
    'aws_sqs_queue_redrive_allow_policy': None,
    'aws_sqs_queue_redrive_policy': None,
    'aws_sqs_queues': None,
    'aws_ssm_activation': None,
    'aws_ssm_association': None,
    'aws_ssm_default_patch_baseline': None,
    'aws_ssm_document': 'aws.management.SystemsManagerDocuments',
    'aws_ssm_instances': None,
    'aws_ssm_maintenance_window': 'aws.management.SystemsManagerMaintenanceWindows',
    'aws_ssm_maintenance_window_target': None,
    'aws_ssm_maintenance_window_task': None,
    'aws_ssm_maintenance_windows': 'aws.management.SystemsManagerMaintenanceWindows',
    'aws_ssm_parameter': 'aws.management.ParameterStore',
    'aws_ssm_parameters_by_path': 'aws.management.ParameterStore',
    'aws_ssm_patch_baseline': None,
    'aws_ssm_patch_group': None,
    'aws_ssm_resource_data_sync': None,
    'aws_ssm_service_setting': None,
    'aws_ssmcontacts_contact': None,
    'aws_ssmcontacts_contact_channel': None,
    'aws_ssmcontacts_plan': None,
    'aws_ssmcontacts_rotation': None,
    'aws_ssmincidents_replication_set': None,
    'aws_ssmincidents_response_plan': None,
    'aws_ssoadmin_account_assignment': 'aws.security.SingleSignOn',
    'aws_ssoadmin_application': None,
    'aws_ssoadmin_application_access_scope': None,
    'aws_ssoadmin_application_assignment': None,
    'aws_ssoadmin_application_assignment_configuration': None,
    'aws_ssoadmin_application_assignments': None,
    'aws_ssoadmin_application_providers': None,
    'aws_ssoadmin_customer_managed_policy_attachment': None,
    'aws_ssoadmin_instance_access_control_attributes': None,
    'aws_ssoadmin_instances': 'aws.security.SingleSignOn',
    'aws_ssoadmin_managed_policy_attachment': None,
    'aws_ssoadmin_permission_set': 'aws.security.IAMPermissions',
    'aws_ssoadmin_permission_set_inline_policy': 'aws.security.IAMPermissions',
    'aws_ssoadmin_permissions_boundary_attachment': None,
    'aws_ssoadmin_principal_application_assignments': None,
    'aws_ssoadmin_trusted_token_issuer': None,
    'aws_storagegateway_cache': None,
    'aws_storagegateway_cached_iscsi_volume': None,
    'aws_storagegateway_file_system_association': None,
    'aws_storagegateway_gateway': None,
    'aws_storagegateway_local_disk': None,
    'aws_storagegateway_nfs_file_share': None,
    'aws_storagegateway_smb_file_share': None,
    'aws_storagegateway_stored_iscsi_volume': None,
    'aws_storagegateway_tape_pool': None,
    'aws_storagegateway_upload_buffer': None,
    'aws_storagegateway_working_storage': None,
    'aws_subnet': None,
    'aws_subnets': None,
    'aws_swf_domain': None,
    'aws_synthetics_canary': None,
    'aws_synthetics_group': None,
    'aws_synthetics_group_association': None,
    'aws_timestreaminfluxdb_db_instance': 'aws.database.Timestream',
    'aws_timestreamwrite_database': 'aws.database.Timestream',
    'aws_timestreamwrite_table': None,
    'aws_transcribe_language_model': 'aws.ml.Transcribe',
    'aws_transcribe_medical_vocabulary': 'aws.ml.Transcribe',
    'aws_transcribe_vocabulary': 'aws.ml.Transcribe',
    'aws_transcribe_vocabulary_filter': None,
    'aws_transfer_access': None,
    'aws_transfer_agreement': None,
    'aws_transfer_certificate': None,
    'aws_transfer_connector': None,
    'aws_transfer_profile': None,
    'aws_transfer_server': None,
    'aws_transfer_ssh_key': None,
    'aws_transfer_tag': None,
    'aws_transfer_user': 'aws.general.User',
    'aws_transfer_workflow': None,
    'aws_verifiedaccess_endpoint': None,
    'aws_verifiedaccess_group': None,
    'aws_verifiedaccess_instance': None,
    'aws_verifiedaccess_instance_logging_configuration': None,
    'aws_verifiedaccess_instance_trust_provider_attachment': None,
    'aws_verifiedaccess_trust_provider': None,
    'aws_verifiedpermissions_identity_source': None,
    'aws_verifiedpermissions_policy': None,
    'aws_verifiedpermissions_policy_store': None,
    'aws_verifiedpermissions_policy_template': None,
    'aws_verifiedpermissions_schema': None,
    'aws_volume_attachment': None,
    'aws_vpc': 'aws.network.VPC',
    'aws_vpc_dhcp_options': None,
    'aws_vpc_dhcp_options_association': None,
    'aws_vpc_endpoint': 'aws.network.Endpoint',
    'aws_vpc_endpoint_connection_accepter': None,
    'aws_vpc_endpoint_connection_notification': None,
    'aws_vpc_endpoint_policy': 'aws.security.IAMPermissions',
    'aws_vpc_endpoint_private_dns': None,
    'aws_vpc_endpoint_route_table_association': None,
    'aws_vpc_endpoint_security_group_association': None,
    'aws_vpc_endpoint_service': None,
    'aws_vpc_endpoint_service_allowed_principal': None,
    'aws_vpc_endpoint_service_private_dns_verification': None,
    'aws_vpc_endpoint_subnet_association': None,
    'aws_vpc_ipam': None,
    'aws_vpc_ipam_organization_admin_account': None,
    'aws_vpc_ipam_pool': None,
    'aws_vpc_ipam_pool_cidr': None,
    'aws_vpc_ipam_pool_cidr_allocation': None,
    'aws_vpc_ipam_pool_cidrs': None,
    'aws_vpc_ipam_pools': None,
    'aws_vpc_ipam_preview_next_cidr': None,
    'aws_vpc_ipam_resource_discovery': None,
    'aws_vpc_ipam_resource_discovery_association': None,
    'aws_vpc_ipam_scope': None,
    'aws_vpc_ipv4_cidr_block_association': None,
    'aws_vpc_ipv6_cidr_block_association': None,
    'aws_vpc_network_performance_metric_subscription': None,
    'aws_vpc_peering_connection': 'aws.network.VPCPeering',
    'aws_vpc_peering_connection_accepter': None,
    'aws_vpc_peering_connection_options': None,
    'aws_vpc_peering_connections': None,
    'aws_vpc_security_group_egress_rule': None,
    'aws_vpc_security_group_ingress_rule': None,
    'aws_vpc_security_group_rule': None,
    'aws_vpc_security_group_rules': None,
    'aws_vpclattice_access_log_subscription': None,
    'aws_vpclattice_auth_policy': None,
    'aws_vpclattice_listener': None,
    'aws_vpclattice_listener_rule': None,
    'aws_vpclattice_resource_policy': None,
    'aws_vpclattice_service': None,
    'aws_vpclattice_service_network': None,
    'aws_vpclattice_service_network_service_association': None,
    'aws_vpclattice_service_network_vpc_association': None,
    'aws_vpclattice_target_group': None,
    'aws_vpclattice_target_group_attachment': None,
    'aws_vpcs': None,
    'aws_vpn_connection': 'aws.network.VpnConnection',
    'aws_vpn_connection_route': None,
    'aws_vpn_gateway': 'aws.network.VpnGateway',
    'aws_vpn_gateway_attachment': None,
    'aws_vpn_gateway_route_propagation': None,
    'aws_waf_byte_match_set': None,
    'aws_waf_geo_match_set': None,
    'aws_waf_ipset': None,
    'aws_waf_rate_based_rule': None,
    'aws_waf_regex_match_set': None,
    'aws_waf_regex_pattern_set': None,
    'aws_waf_rule': 'aws.security.WAFFilteringRule',
    'aws_waf_rule_group': None,
    'aws_waf_size_constraint_set': None,
    'aws_waf_sql_injection_match_set': None,
    'aws_waf_subscribed_rule_group': None,
    'aws_waf_web_acl': None,
    'aws_waf_xss_match_set': None,
    'aws_wafregional_byte_match_set': None,
    'aws_wafregional_geo_match_set': None,
    'aws_wafregional_ipset': None,
    'aws_wafregional_rate_based_rule': None,
    'aws_wafregional_regex_match_set': None,
    'aws_wafregional_regex_pattern_set': None,
    'aws_wafregional_rule': 'aws.security.WAFFilteringRule',
    'aws_wafregional_rule_group': None,
    'aws_wafregional_size_constraint_set': None,
    'aws_wafregional_sql_injection_match_set': None,
    'aws_wafregional_subscribed_rule_group': None,
    'aws_wafregional_web_acl': None,
    'aws_wafregional_web_acl_association': None,
    'aws_wafregional_xss_match_set': None,
    'aws_wafv2_ip_set': None,
    'aws_wafv2_regex_pattern_set': None,
    'aws_wafv2_rule_group': None,
    'aws_wafv2_web_acl': None,
    'aws_wafv2_web_acl_association': None,
    'aws_wafv2_web_acl_logging_configuration': None,
    'aws_worklink_fleet': None,
    'aws_worklink_website_certificate_authority_association': None,
    'aws_workspaces_bundle': None,
    'aws_workspaces_connection_alias': None,
    'aws_workspaces_directory': None,
    'aws_workspaces_image': None,
    'aws_workspaces_ip_group': None,
    'aws_workspaces_workspace': 'aws.enduser.Workspaces',
    'aws_xray_encryption_config': None,
    'aws_xray_group': 'aws.devtools.XRay',
    'aws_xray_sampling_rule': None,
}



# -*- coding: utf-8 -*-
from tfdiagrams import resources

from diagrams import Diagram
from diagrams import setdiagram
from pathlib import Path

import diagrams.aws.analytics
import diagrams.aws.ar
import diagrams.aws.blockchain
import diagrams.aws.business
import diagrams.aws.compute
import diagrams.aws.cost
import diagrams.aws.database
import diagrams.aws.devtools
import diagrams.aws.enablement
import diagrams.aws.enduser
import diagrams.aws.engagement
import diagrams.aws.game
import diagrams.aws.general
import diagrams.aws.integration
import diagrams.aws.iot
import diagrams.aws.management
import diagrams.aws.media
import diagrams.aws.migration
import diagrams.aws.ml
import diagrams.aws.mobile
import diagrams.aws.network
import diagrams.aws.quantum
import diagrams.aws.robotics
import diagrams.aws.satellite
import diagrams.aws.security
import diagrams.aws.storage
import os
import pydot
import re

EXCLUDE_NODES = [
    # global
    'output',
    'var',
]


class BlankGraph(Diagram):
    def __exit__(self, exc_type, exc_value, traceback):
        # self.render()
        setdiagram(None)


class Diagram:
    def set_node_styles(self, node):
        node.set_fixedsize('true')
        node.set_fontcolor('#2D3436')
        node.set_height(2.2)
        node.set_width(1.4)
        node.set_style('rounded')
        node.set_shape('none')

    def replace_node(self, node):
        node_name = node.get_name()
        if ' ' in node_name:
            label_items = node_name.replace('"', '').split(' ')[0].split('.')
        else:
            label_items = node_name.replace('"', '').split('.')
        resource_instance = None
        for i in label_items:
            if i in resources.RESOURCES_MAP:
                if resources.RESOURCES_MAP[i]:
                    resource_instance = eval('diagrams.' + resources.RESOURCES_MAP[i] + '()')
                    break

        if resource_instance:
            node.set_image(resource_instance._load_icon())
            self.set_node_styles(node)
        else:
            node.set_height(0.0)

        # label break
        height = node.get_height()
        label = ''
        line_break = False
        for i in label_items:
            if not len(label) == 0:
                label += '.'
            label += i
            if i.startswith('aws_'):
                label += '\\n'
                height += 0.4
            elif line_break:
                label += '\\n'
                height += 0.4
                line_break = False
            if 'module' in i:
                line_break = True
        node.set_label(label)
        node.set_height(height)

        # check exclude keywords
        items = []
        for i in self.excludes:
            for j in label_items:
                if i == j \
                        or ('*' in i and re.search(i.replace('*', '.*'), j)):
                    # Allow exact match or wildcard
                    items += i
        if len(items) == 0:
            node.set_name(node_name)
            return node

        return None


    def add_node(self, graph, node):
        node_name = node.get_name()
        if node_name != 'node' and node_name != '"\\n"':
            new_node = self.replace_node(node)
            if new_node:
                graph.add_node(new_node)


    def __init__(self, dot: str = "", name: str = 'tfdiagrams', outformat: str = 'png', filename: str = 'tfdiagrams.png',
                 excludes: str = ''):
        self.dot = dot
        self.name = name
        self.outformat = outformat
        self.filename = filename
        self.excludes = EXCLUDE_NODES + excludes.split(',')

        with BlankGraph():
            # load object from dot file
            (graph,) = pydot.graph_from_dot_data(self.dot)

            # graph settings
            new_graph = pydot.Dot(graph_type='digraph')
            new_graph.set_graph_defaults(fontcolor='#2D3436', fontname='sans-serif', fontsize=15,
                                         label='"' + self.name + '"')
            #                              nodesep=0.60, pad=2.0, rankdir='LR', ranksep=2.30, splines='ortho')
            new_graph.set_node_defaults(fontcolor='#2D3436', fontname='sans-serif', fontsize=13,
                        imagescale='true', labelloc='b', shape='box')

            new_graph.set_rankdir("RL")

            basedir = Path(os.path.abspath(os.path.dirname(__file__)))
            self.blank_image = os.path.join(basedir.parent, 'tfdiagrams/resources/blank.png')

            # add nodes
            for node in graph.get_node_list():
                if node.get_name() != '"\\n"':
                    self.add_node(new_graph, node)

            # add subgraphs
            for subgraph in graph.get_subgraph_list():
                h = pydot.Subgraph(subgraph.get_name())
                h.set_label(subgraph.get_label())
                for node in subgraph.get_node_list():
                    if node.get_name() != '"\\n"':
                        self.add_node(h, node)
                new_graph.add_subgraph(h)

            # add edges
            for edge in graph.get_edge_list():
                source_name = edge.get_source()
                if ' ' in source_name:
                    source_items = source_name.replace('"', '').split(' ')[0].split('.')
                else:
                    source_items = source_name.replace('"', '').split('.')
                destination_name = edge.get_destination()
                if ' ' in destination_name:
                    destination_items = destination_name.replace('"', '').split(' ')[0].split('.')
                else:
                    destination_items = destination_name.replace('"', '').split('.')

                # check exclude keywords
                items = []
                for i in self.excludes:
                    for j in source_items + destination_items:
                        if i == j \
                                or ('*' in i and re.search(i.replace('*', '.*'), j)):
                            # Allow exact match or wildcard
                            items += i
                if len(items) == 0:
                    new_edge = pydot.Edge(source_name, destination_name)
                    new_graph.add_edge(new_edge)

            # output graph file
            new_graph.write(self.filename, format=self.outformat, prog='dot')
